#[non_exhaustive]pub enum SchemaDialect {
Draft07,
Draft2020_12,
}Expand description
JSON Schema draft used when generating schemas from Rust types.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Draft07
Draft-07: the dialect providers and adapter transforms are built on.
Draft2020_12
Draft 2020-12.
Implementations
Sourceimpl SchemaDialect
impl SchemaDialect
Sourcepub fn settings(self) -> SchemaSettings
pub fn settings(self) -> SchemaSettings
Returns the schemars settings for this dialect.
Sourcepub fn generate<T: JsonSchema>(self) -> Value
pub fn generate<T: JsonSchema>(self) -> Value
Generates the root schema of T as a JSON value.
Sourcepub fn meta_schema(self) -> &'static str
pub fn meta_schema(self) -> &'static str
Returns the $schema URI of this dialect.