#[non_exhaustive]pub enum SchemaError {
JsonParse(JsonParseError),
TypeValidation(TypeValidationError),
UnsupportedTransform {
transform: &'static str,
keyword: &'static str,
},
InvalidSchema {
message: String,
},
}Expand description
Errors produced while parsing or validating JSON against a schema.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
JsonParse(JsonParseError)
The text is not valid JSON.
TypeValidation(TypeValidationError)
The value does not match the schema or type.
UnsupportedTransform
A valid schema shape cannot be preserved by the requested transform.
Fields
InvalidSchema
The JSON Schema itself is invalid.