Module validation

Module validation 

Dynamic JSON Schema validation.

ValidationIssue / ValidationIssues are always available so custom validators can report structured problems. The Validator that checks a value against a raw JSON Schema requires the json-schema-validation feature.

Structs

ValidationIssue
One validation problem.
ValidationIssues
A set of validation problems, usable as an error cause.
Validator
A compiled JSON Schema validator using the declared dialect.