Provider-oriented JSON Schema rewrites.
Enums
- Schema
Transform - A rewrite applied to a JSON Schema before it is sent to a provider.
Functions
- add_
additional_ properties_ false - Sets
additionalProperties: falseon every object schema that does not already declare a schema for additional properties. - remove_
property_ names - Removes
propertyNamesfrom every schema. - to_
openai_ strict - Rewrites a schema for OpenAI strict mode.